/*
 * MPU9250.h
 *
 *  Created on: Aug 6, 2017
 *      Author: Christopher Hunt <chunt11@jhmi.edu>
 */

#ifndef MPU9250_H_
#define MPU9250_H_

#include "common.h"

#include "app_timer.h"
#include "nrf_drv_clock.h"
#include "app_util_platform.h"

#include "nrf_gpiote.h"
#include "nrf_drv_gpiote.h"
#include "nrf_twi.h"
#include "nrf_drv_twi.h"

#include "constants.h"

// define

#define APP_TIMER_PRESCALER		0
#define OP_QUEUES_SIZE			4

// typedefs

typedef enum { ACCEL_RANGE_2G = 0,
			   ACCEL_RANGE_4G,
			   ACCEL_RANGE_8G,
			   ACCEL_RANGE_16G } accel_range_t;

typedef enum { GYRO_RANGE_250DPS = 0,
    		   GYRO_RANGE_500DPS,
			   GYRO_RANGE_1000DPS,
			   GYRO_RANGE_2000DPS } gyro_range_t;

typedef enum MAG_RANGE { MFS_14BITS = 0,
    					 MFS_16BITS } mag_range_t;

typedef enum DLPF_BANDWIDTH { DLPF_BANDWIDTH_184HZ = 0,
    						  DLPF_BANDWIDTH_92HZ,
							  DLPF_BANDWIDTH_41HZ,
							  DLPF_BANDWIDTH_20HZ,
							  DLPF_BANDWIDTH_10HZ,
							  DLPF_BANDWIDTH_5HZ } dlpf_bandwidth_t;

// I2C functions

void i2c_event_handler( nrf_drv_twi_evt_t const * p_event, void * p_context );

// Calibrate functions

void calibrate_mpu9250( void );

void calibrate_ak8963( void );

const float * get_calibration( void );

void set_calibration( const float * c_data );


// Data functions

bool init_imu( void );

void update_imu_data( void );

void compute_orientation( void );

const float * get_orientation( void );

const float * get_accelerometer( void );

const float * get_gyroscope( void );

const float * get_magnetometer( void );

const float get_temperature( void );

#endif /* MPU9250_H_ */
